"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const qwik = require("@builder.io/qwik");
const build = require("@builder.io/qwik/build");
const preact = require("preact");
const jsxRuntime = require("@builder.io/qwik/jsx-runtime");
const preactRenderToString = require("preact-render-to-string");
const SlotCtx = preact.createContext({
  scopeId: ""
});
function main(slotEl, scopeId, RootCmp, props) {
  const newProps = getPreactProps(props);
  return mainExactProps(slotEl, scopeId, RootCmp, newProps);
}
function mainExactProps(slotEl, scopeId, RootCmp, props) {
  return preact.createElement(SlotCtx.Provider, {
    value: {
      el: slotEl,
      scopeId,
      attachedEl: void 0
    },
    children: preact.createElement(RootCmp, {
      ...props,
      children: preact.createElement(SlotElement, null)
    })
  });
}
class SlotElement extends preact.Component {
  constructor() {
    super(...arguments);
    this.slotC = preact.createRef();
  }
  shouldComponentUpdate() {
    return false;
  }
  componentDidMount() {
    const slotC = this.slotC.current;
    if (slotC) {
      const { attachedEl, el } = this.context;
      if (el) {
        if (!attachedEl)
          slotC.appendChild(el);
        else if (attachedEl !== slotC)
          throw new Error("already attached");
      }
    }
  }
  render() {
    return preact.createElement("q-slotc", {
      class: this.context.scopeId,
      suppressHydrationWarning: true,
      dangerouslySetInnerHTML: {
        __html: "<!--SLOT-->"
      },
      ref: this.slotC
    });
  }
}
SlotElement.contextType = SlotCtx;
const getPreactProps = (props) => {
  const obj = {};
  Object.keys(props).forEach((key) => {
    if (!key.startsWith("client:") && !key.startsWith(HOST_PREFIX)) {
      const normalizedKey = key.endsWith("$") ? key.slice(0, -1) : key;
      obj[normalizedKey] = props[key];
    }
  });
  return obj;
};
const getHostProps = (props) => {
  const obj = {};
  Object.keys(props).forEach((key) => {
    if (key.startsWith(HOST_PREFIX))
      obj[key.slice(HOST_PREFIX.length)] = props[key];
  });
  return obj;
};
const useWakeupSignal = (props, opts = {}) => {
  const signal = qwik.useSignal(false);
  const activate = /* @__PURE__ */ qwik.inlinedQrl(() => {
    const [signal2] = qwik.useLexicalScope();
    return signal2.value = true;
  }, "useWakeupSignal_activate_LivqdLHHXds", [
    signal
  ]);
  const clientOnly = !!(props["client:only"] || opts?.clientOnly);
  if (build.isServer) {
    if (props["client:visible"] || opts?.eagerness === "visible")
      qwik.useOn("qvisible", activate);
    if (props["client:idle"] || opts?.eagerness === "idle")
      qwik.useOnDocument("qidle", activate);
    if (props["client:load"] || clientOnly || opts?.eagerness === "load")
      qwik.useOnDocument("qinit", activate);
    if (props["client:hover"] || opts?.eagerness === "hover")
      qwik.useOn("mouseover", activate);
    if (props["client:event"])
      qwik.useOn(props["client:event"], activate);
    if (opts?.event)
      qwik.useOn(opts?.event, activate);
  }
  return [
    signal,
    clientOnly,
    activate
  ];
};
const HOST_PREFIX = "host:";
async function renderFromServer(Host, preactCmp$, scopeId, props, ref, slotRef, hydrationProps) {
  if (build.isServer) {
    const Cmp = await preactCmp$.resolve();
    const newProps = getPreactProps(props);
    Object.assign(hydrationProps, newProps);
    const html = preactRenderToString.renderToString(mainExactProps(void 0, scopeId, Cmp, newProps));
    const index = html.indexOf("<!--SLOT-->");
    if (index > 0) {
      const part1 = html.slice(0, index);
      const part2 = html.slice(index + 11);
      return /* @__PURE__ */ qwik._jsxC(Host, {
        ref,
        ...getHostProps(props),
        children: /* @__PURE__ */ qwik._jsxC(qwik.SSRStream, {
          children: async function* () {
            yield /* @__PURE__ */ qwik._jsxC(qwik.SSRRaw, {
              data: part1
            }, 3, "wL_0");
            yield /* @__PURE__ */ qwik._jsxQ("q-slot", {
              ref: slotRef
            }, null, /* @__PURE__ */ qwik._jsxC(qwik.Slot, null, 3, "wL_1"), 1, null);
            yield /* @__PURE__ */ qwik._jsxC(qwik.SSRRaw, {
              data: part2
            }, 3, "wL_2");
          }
        }, 1, "wL_3")
      }, 0, "wL_4");
    }
    return /* @__PURE__ */ qwik._jsxC(jsxRuntime.Fragment, {
      children: [
        /* @__PURE__ */ qwik._jsxC(Host, {
          children: /* @__PURE__ */ qwik._jsxC(qwik.SSRRaw, {
            data: html
          }, 3, "wL_5"),
          ref
        }, 1, "wL_6"),
        /* @__PURE__ */ qwik._jsxQ("q-slot", {
          ref: slotRef
        }, null, /* @__PURE__ */ qwik._jsxC(qwik.Slot, null, 3, "wL_7"), 1, null)
      ]
    }, 1, "wL_8");
  }
}
function qwikifyQrl(preactCmp$, opts) {
  return /* @__PURE__ */ qwik.componentQrl(/* @__PURE__ */ qwik.inlinedQrl((props) => {
    const [opts2, preactCmp$2] = qwik.useLexicalScope();
    qwik._jsxBranch();
    const stylesscoped$ = qwik.useStylesScopedQrl(/* @__PURE__ */ qwik.inlinedQrl(`q-slot{display:none} q-slotc,q-slotc>q-slot{display:contents}`, "qwikifyQrl_component_stylesscoped_useStylesScoped_t1IhyDL6tNM"));
    const hostRef = qwik.useSignal();
    const slotRef = qwik.useSignal();
    const internalState = qwik.useSignal();
    const [signal, isClientOnly] = useWakeupSignal(props, opts2);
    const hydrationKeys = {};
    const TagName = opts2?.tagName ?? "qwik-preact";
    qwik.useTaskQrl(/* @__PURE__ */ qwik.inlinedQrl(async ({ track }) => {
      const [hostRef2, hydrationKeys2, internalState2, isClientOnly2, preactCmp$3, props2, signal2, slotRef2, stylesscoped$2] = qwik.useLexicalScope();
      const trackedProps = track(() => ({
        ...props2
      }));
      track(signal2);
      if (!build.isBrowser)
        return;
      if (internalState2.value) {
        if (internalState2.value.root)
          preact.render(main(slotRef2.value, stylesscoped$2.scopeId, internalState2.value.cmp, trackedProps), internalState2.value.root);
      } else {
        const Cmp = await preactCmp$3.resolve();
        const hostElement = hostRef2.value;
        if (hostElement) {
          if (!isClientOnly2)
            preact.hydrate(mainExactProps(slotRef2.value, stylesscoped$2.scopeId, Cmp, hydrationKeys2), hostElement);
          if (isClientOnly2 || signal2.value === false)
            preact.render(main(slotRef2.value, stylesscoped$2.scopeId, Cmp, trackedProps), hostElement);
        }
        internalState2.value = qwik.noSerialize({
          cmp: Cmp,
          root: hostElement
        });
      }
    }, "qwikifyQrl_component_useTask_vR8CXB33lQg", [
      hostRef,
      hydrationKeys,
      internalState,
      isClientOnly,
      preactCmp$2,
      props,
      signal,
      slotRef,
      stylesscoped$
    ]));
    if (build.isServer && !isClientOnly) {
      const jsx = renderFromServer(TagName, preactCmp$2, stylesscoped$.scopeId, props, hostRef, slotRef, hydrationKeys);
      return /* @__PURE__ */ qwik._jsxC(qwik.RenderOnce, {
        children: jsx
      }, 1, 2);
    }
    return /* @__PURE__ */ qwik._jsxC(qwik.RenderOnce, {
      children: [
        /* @__PURE__ */ qwik._jsxC(TagName, {
          ...getHostProps(props),
          children: qwik.SkipRender,
          ref: (el) => {
            if (build.isBrowser)
              queueMicrotask(() => {
                const internalData = internalState.value;
                if (internalData && !internalData.root)
                  preact.render(main(slotRef.value, stylesscoped$.scopeId, internalData.cmp, props), el);
              });
            else
              hostRef.value = el;
          },
          [qwik._IMMUTABLE]: {
            ref: qwik._IMMUTABLE
          }
        }, 0, "us_0"),
        /* @__PURE__ */ qwik._jsxQ("q-slot", {
          ref: slotRef
        }, null, /* @__PURE__ */ qwik._jsxC(qwik.Slot, null, 3, "us_1"), 1, null)
      ]
    }, 1, "us_2");
  }, "qwikifyQrl_component_POm0kRPUtKs", [
    opts,
    preactCmp$
  ]));
}
const qwikify$ = /* @__PURE__ */ qwik.implicit$FirstArg(qwikifyQrl);
exports.qwikify$ = qwikify$;
exports.qwikifyQrl = qwikifyQrl;
